==> q-4.6.tar.gz: q-4.6/src/qc.h <==
/* A Bison parser, made from /home/ag/cvs/q/q/src/qc.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_Y_TAB_H
# define BISON_Y_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     AND = 258,
     AS = 259,
     CONST = 260,
     DEF = 261,
     DIV = 262,
     ELSE = 263,
     EXTERN = 264,
     IF = 265,
     IMPORT = 266,
     IN = 267,
     INCLUDE = 268,
     MOD = 269,
     NOT = 270,
     OR = 271,
     OTHERWISE = 272,
     PRIVATE = 273,
     PUBLIC = 274,
     SPECIAL = 275,
     THEN = 276,
     TYPE = 277,
     UNDEF = 278,
     VAR = 279,
     WHERE = 280,
     CAT = 281,
     DBAR = 282,
     LEQ = 283,
     GEQ = 284,
     NEQ = 285,
     STR = 286,
     UID = 287,
     LID = 288,
     QUID = 289,
     QLID = 290,
     STR1 = 291,
     INT = 292,
     FLOAT = 293,
     ERRTOK = 294,
     EOFTOK = 295
   };
#endif
#define AND 258
#define AS 259
#define CONST 260
#define DEF 261
#define DIV 262
#define ELSE 263
#define EXTERN 264
#define IF 265
#define IMPORT 266
#define IN 267
#define INCLUDE 268
#define MOD 269
#define NOT 270
#define OR 271
#define OTHERWISE 272
#define PRIVATE 273
#define PUBLIC 274
#define SPECIAL 275
#define THEN 276
#define TYPE 277
#define UNDEF 278
#define VAR 279
#define WHERE 280
#define CAT 281
#define DBAR 282
#define LEQ 283
#define GEQ 284
#define NEQ 285
#define STR 286
#define UID 287
#define LID 288
#define QUID 289
#define QLID 290
#define STR1 291
#define INT 292
#define FLOAT 293
#define ERRTOK 294
#define EOFTOK 295




#ifndef YYSTYPE
#line 55 "qc.y"
typedef union {
  int ival;
  mpz_t zval;
  double fval;
  char *sval;
  EXPR *xval;
} yystype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 128 "y.tab.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_Y_TAB_H */

==> q-6.2.tar.gz: q-6.2/src/qc.h <==
/* A Bison parser, made by GNU Bison 1.875.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     AND = 258,
     AS = 259,
     CONST = 260,
     DEF = 261,
     DIV = 262,
     ELSE = 263,
     EXTERN = 264,
     IF = 265,
     IMPORT = 266,
     INCLUDE = 267,
     MOD = 268,
     NOT = 269,
     OR = 270,
     OTHERWISE = 271,
     PRIVATE = 272,
     PUBLIC = 273,
     SPECIAL = 274,
     THEN = 275,
     TYPE = 276,
     UNDEF = 277,
     VAR = 278,
     WHERE = 279,
     DOTDOT = 280,
     CAT = 281,
     DBAR = 282,
     LEQ = 283,
     GEQ = 284,
     NEQ = 285,
     STR = 286,
     UID = 287,
     LID = 288,
     QUID = 289,
     QLID = 290,
     STR1 = 291,
     INT = 292,
     FLOAT = 293,
     OP0 = 294,
     OP1 = 295,
     OP2 = 296,
     OP3 = 297,
     OP4 = 298,
     OP5 = 299,
     OP6 = 300,
     OP7 = 301,
     OP8 = 302,
     OP9 = 303,
     ERRTOK = 304,
     EOFTOK = 305
   };
#endif
#define AND 258
#define AS 259
#define CONST 260
#define DEF 261
#define DIV 262
#define ELSE 263
#define EXTERN 264
#define IF 265
#define IMPORT 266
#define INCLUDE 267
#define MOD 268
#define NOT 269
#define OR 270
#define OTHERWISE 271
#define PRIVATE 272
#define PUBLIC 273
#define SPECIAL 274
#define THEN 275
#define TYPE 276
#define UNDEF 277
#define VAR 278
#define WHERE 279
#define DOTDOT 280
#define CAT 281
#define DBAR 282
#define LEQ 283
#define GEQ 284
#define NEQ 285
#define STR 286
#define UID 287
#define LID 288
#define QUID 289
#define QLID 290
#define STR1 291
#define INT 292
#define FLOAT 293
#define OP0 294
#define OP1 295
#define OP2 296
#define OP3 297
#define OP4 298
#define OP5 299
#define OP6 300
#define OP7 301
#define OP8 302
#define OP9 303
#define ERRTOK 304
#define EOFTOK 305




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 62 "qc.y"
typedef union YYSTYPE {
  int ival;
  mpz_t zval;
  double fval;
  char *sval;
  EXPR *xval;
  xvect_t *xvval;
} YYSTYPE;
/* Line 1249 of yacc.c.  */
#line 145 "qc.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE yylval;
